---
title: APIs
tags: technology, documentation
---

### FinX Capital Markets LLC

Please see LICENSE and SECURITY for terms of use.

***

# FinX Python Software Development Kit

The **FinX SDK** is a python package that has interfaces to the FinX Capital Markets
Analytics Platform (the 'FinX Platform'). The code in the SDK makes calls to REST APIs 
& WebSocket endpoints. A valid ___FinX API Key___ is required for the SDK to return results.

To obtain an API Key, please contact us FinX Capital Markets LLC [via email](mailto:info@finx.io).

***

## Introduction

This document is the definitive source of information for using the FinX SDK.

---
title: APIs
tags: technology, documentation
---

# Developer Notes - FinX SDK

The **FinX SDK** is a python package that has interfaces to the FinX Capital Markets
Analytics Platform (the 'FinX Platform'). The code in the SDK makes calls to REST APIs 
& WebSocket endpoints. A valid ___FinX API Key___ is required for the SDK to return results.

To obtain an API Key, please contact us FinX Capital Markets LLC [via email](mailto:info@finx.io).

Please see LICENSE and SECURITY for terms of use.

***

# Technical Documentation - FinX SDK

Technical docs may be found at [http://docs.finx.io](http://docs.finx.io)

